@@ -1,4 +1,5 @@
 ## Copyright (C) 2008 Soren Hauberg
+## Copyright (C) 2010 Carnë Draug <carandraug+dev@gmail.com>
 ## 
 ## This program is free software; you can redistribute it and/or
 ## modify it under the terms of the GNU General Public License
@@ -31,5 +32,16 @@ function retval = imdilate(im, se)
   endif
 
   ## Perform filtering
-  retval = ordfiltn(im, sum(se(:)!=0), se, 0);
+  ## Filtering must be done with the reflection of the structuring element (they
+  ## are not always symmetrical)
+  se      = imrotate(se, 180);
+
+  ## If image is binary/logical, try to use filter2 (much faster)
+  if (islogical(im))
+    # The following line comes from the function dilate, copyright by Josep Mones i Teixidor
+    retval  = filter2(se,im)>0;
+  else
+    retval  = ordfiltn(im, sum(se(:)!=0), se, 0);
+  endif
+
 endfunction
